// Copyright  2007 Konesans Ltd.  For educational purposes only. Distribution in any form is strictly forbidden.

#region Using directives

using System;
using System.Collections;
using System.Windows.Forms;
using System.Windows.Forms.Design;
using Microsoft.SqlServer.Dts.Runtime;
using Microsoft.SqlServer.Dts.Runtime.Design;

#endregion

namespace Konesans.Dts.Runtime.SimpleTask5
{
    /// <summary>
    /// List box user control for UITypeEditor FileConnectionTypeEditor 
    /// </summary>
    internal class FileConnectionTypeEditorControl : ListBox
    {
        #region Private Variables & Constants
        private IWindowsFormsEditorService _windowsFormsEditorService;
        private IDtsConnectionService _dtsConnectionService;        
        private const string ConnectionType = "FILE";
        private const string NewConnectionTag = "<New connection...>";
        #endregion

        #region Ctor
        public FileConnectionTypeEditorControl(IDtsConnectionService dtsConnectionService, IWindowsFormsEditorService windowsFormsEditorService)
        {
            _dtsConnectionService = dtsConnectionService;
            _windowsFormsEditorService = windowsFormsEditorService;

            BorderStyle = BorderStyle.None;
        }
        #endregion

        #region PopulateConnectionsCombo
        internal void PopulateConnectionsCombo(string selectedItem)
        {
            Items.Clear();

            if (selectedItem == null)
                selectedItem = Text;

            if (_dtsConnectionService != null)
            {
                Items.Add(NewConnectionTag);
                foreach (ConnectionManager connectionManager in _dtsConnectionService.GetConnectionsOfType(ConnectionType))
                {
                    Items.Add(connectionManager.Name);
                }
            }

            SelectedItem = selectedItem;
        }
        #endregion

        #region OnSelectedValueChanged
        protected override void OnSelectedValueChanged(EventArgs e)
        {
            base.OnSelectedValueChanged(e);

            _windowsFormsEditorService.CloseDropDown();

            if (SelectedIndex == 0)
            {
                string selectedText = Text;
                SelectedItem = "";

                if (selectedText == NewConnectionTag)
                    CreateNewConnection();
                else
                    SelectedItem = selectedText;

            }
        }

        private void CreateNewConnection()
        {
            ArrayList newConns = _dtsConnectionService.CreateConnection(ConnectionType);
            if (newConns.Count > 0)
            {
                ConnectionManager newConn = (ConnectionManager)newConns[0];
                PopulateConnectionsCombo(newConn.Name);
            }
            else
            {
                SelectedItem = null;
            }
        }
        #endregion

        #region Designer Code

        /// <summary> 
        /// Required designer variable.
        /// </summary>
        private System.ComponentModel.IContainer components = null;

        /// <summary> 
        /// Clean up any resources being used.
        /// </summary>
        protected override void Dispose(bool disposing)
        {
            if (disposing && (components != null))
            {
                components.Dispose();
            }
            base.Dispose(disposing);
        }

        #region Component Designer generated code

        /// <summary> 
        /// Required method for Designer support - do not modify 
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
            components = new System.ComponentModel.Container();
        }

        #endregion

        #endregion
    }
}
