// Copyright  2007 Konesans Ltd.  For educational purposes only. Distribution in any form is strictly forbidden.

#region Using directives

using System;
using System.Drawing;
using System.Windows.Forms;
using Microsoft.SqlServer.Dts.Runtime;
using Microsoft.SqlServer.Dts.Runtime.Design;
using Microsoft.SqlServer.MessageBox;

#endregion

namespace Konesans.Dts.Runtime.SimpleTask5
{
    public partial class SimpleTaskUIForm : Form
    {
        #region Private variables
        private TaskHost _taskHost = null;
        private IDtsConnectionService _dtsConnectionService = null;
        #endregion

        #region Ctor
        public SimpleTaskUIForm(TaskHost taskHost, IDtsConnectionService dtsConnectionService)
        {
            // Store parameters for later use
            _taskHost = taskHost;
            _dtsConnectionService = dtsConnectionService;

            InitializeComponent();

            // Get task icon by resource string from assembly resource stream, see DtsTask.IconResource on task class for string
            Icon = new Icon(typeof(SimpleTask5).Assembly.GetManifestResourceStream("Konesans.Dts.Runtime.SimpleTask5.Square.ico"));

            foreach(ConnectionManager connectionManager in _dtsConnectionService.GetConnectionsOfType("FILE"))
            {
                comboBoxFileConnection.Items.Add(connectionManager.Name);
            }


            // Load properties
            numericUpDownCount.Value =
                Convert.ToInt32(_taskHost.Properties[SimpleTask5.Property_CountProperty].GetValue(taskHost));
            comboBoxFileConnection.Text = _taskHost.Properties[SimpleTask5.Property_FileConnection].GetValue(taskHost) as string;
            textBoxPassword.Text = "";
        }
        #endregion

        #region OK Click Event
        private void buttonOK_Click(object sender, EventArgs e)
        {
            // Save properties on OK

            buttonOK.DialogResult = DialogResult.None;
            
            try
            {
                _taskHost.Properties[SimpleTask5.Property_CountProperty].SetValue(_taskHost,
                                                                                  Convert.ToInt32(numericUpDownCount.Value));
                _taskHost.Properties[SimpleTask5.Property_FileConnection].SetValue(_taskHost,
                                                                                   comboBoxFileConnection.Text);
                
                _taskHost.Properties[SimpleTask5.Property_Password].SetValue(_taskHost, textBoxPassword.Text);

                buttonOK.DialogResult = DialogResult.OK;
            }
            catch (Exception ex)
            {
                ExceptionMessageBox messageBox = new ExceptionMessageBox(ex);
                messageBox.Show(this); 
            }
        }
        #endregion
    }
}